==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/emulator/dialogs_de.lua <==

dialogId("zx-m-pametnici", "font_small", "So this is a level for real connoisseurs.")
dialogStr("Das ist mal eine Ebene für echte Kenner.")


dialogId("zx-v-osmibit", "font_big", "Yeah, I feel like I can feel the eight bit wind of history.")
dialogStr("Ja, ich spüre den Acht-Bit-Wind der Geschichte.")


dialogId("zx-m-pixel", "font_small", "Can you see that pixel graphic all around us? I must confess I feel nostalgic.")
dialogStr("Siehst du die Pixelgrafik um uns herum? Ich muss zugeben, dass ich nostalgisch werden.")


dialogId("zx-v-hry", "font_big", "This is an opportunity to play the merry old games of ZX Spectrum.")
dialogStr("Das ist die Gelegenheit, alte ZX-Spectrum-Spiele zu zocken.")


dialogId("zx-m-premyslis", "font_small", "What are you thinking about now?")
dialogStr("Worüber denkst du gerade nach?")


dialogId("zx-v-pamet", "font_big", "Well, I just realized that the animations of us two alone would fill up the RAM of a ZX Spectrum.")
dialogStr("Nunja, mir ist gerade klar geworden, dass allein unsere Animation den Arbeitsspeicher des ZX Spectrum gefüllt hätte.")


dialogId("zx-v-otazka", "font_big", "Do you know that your question alone in WAV format would overfill the RAM of ZX Spectrum? And imagine how many such sounds are in this game.")
dialogStr("Weißt du, dass allein deine Frage als WAV-Datei den Arbeitsspeicher des ZX Spectrum überfüllt hätte? Und stell dir vor, wie viele dieser Töne in diesem Spiel sind.")


dialogId("zx-m-necodosebe", "font_small", "But still, these games had something to them, didn`t they?")
dialogStr("Trotzdem hatten diese Spiele etwas an sich, oder?")


dialogId("zx-m-knight", "font_small", "Can you see that Knight Lorer?")
dialogStr("Siehst du diesen Knight Lorer?")


dialogId("zx-v-manicminer", "font_big", "And that must be the Manic Miner.")
dialogStr("Und das muss der Manic Miner sein.")


dialogId("zx-m-jetpack", "font_small", "I really didn`t know I`d ever be putting the Jetpack together again.")
dialogStr("Ich hätte nie gedacht, dass ich nochmal dieses Jetpack zusammenstelle.")


dialogId("zx-v-roboti", "font_big", "This line of robots looks familiar.")
dialogStr("Diese Baureihe Roboter sieht bekannt aus.")


dialogId("zx-m-highway", "font_small", "Oh sure, they are from the Highway Encounter.")
dialogStr("Ja sicher, die sind aus Highway Encounter.")


dialogId("zx-v-nahravani", "font_big", "I wonder what is loading right now.")
dialogStr("Ich frage mich, was gerade lädt.")


dialogId("zx-m-ocel", "font_small", "The single biggest advantage of this room is that it contains no steel.")
dialogStr("Der größte Vorteil des Raumes ist, dass hier kein Stahl ist.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/emulator/dialogs_de.lua <==

dialogId("zx-m-pametnici", "font_small", "So this is a level for real connoisseurs.")
dialogStr("Das ist mal eine Ebene für echte Kenner.")


dialogId("zx-v-osmibit", "font_big", "Yeah, I feel like I can feel the eight bit wind of history.")
dialogStr("Ja, ich spüre den Acht-Bit-Wind der Geschichte.")


dialogId("zx-m-pixel", "font_small", "Can you see that pixel graphic all around us? I must confess I feel nostalgic.")
dialogStr("Siehst du die Pixelgrafik um uns herum? Ich muss zugeben, dass ich nostalgisch werden.")


dialogId("zx-v-hry", "font_big", "This is an opportunity to play the merry old games of ZX Spectrum.")
dialogStr("Das ist die Gelegenheit, alte ZX-Spectrum-Spiele zu zocken.")


dialogId("zx-m-premyslis", "font_small", "What are you thinking about now?")
dialogStr("Worüber denkst du gerade nach?")


dialogId("zx-v-pamet", "font_big", "Well, I just realized that the animations of us two alone would fill up the RAM of a ZX Spectrum.")
dialogStr("Nunja, mir ist gerade klar geworden, dass allein unsere Animation den Arbeitsspeicher des ZX Spectrum gefüllt hätte.")


dialogId("zx-v-otazka", "font_big", "Do you know that your question alone in WAV format would overfill the RAM of ZX Spectrum? And imagine how many such sounds are in this game.")
dialogStr("Weißt du, dass allein deine Frage als WAV-Datei den Arbeitsspeicher des ZX Spectrum überfüllt hätte? Und stell dir vor, wie viele dieser Töne in diesem Spiel sind.")


dialogId("zx-m-necodosebe", "font_small", "But still, these games had something to them, didn’t they?")
dialogStr("Trotzdem hatten diese Spiele etwas an sich, oder?")


dialogId("zx-m-knight", "font_small", "Can you see that Knight Lorer?")
dialogStr("Siehst du diesen Knight Lorer?")


dialogId("zx-v-manicminer", "font_big", "And that must be the Manic Miner.")
dialogStr("Und das muss der Manic Miner sein.")


dialogId("zx-m-jetpack", "font_small", "I really didn’t know I’d ever be putting the Jetpack together again.")
dialogStr("Ich hätte nie gedacht, dass ich nochmal dieses Jetpack zusammenstelle.")


dialogId("zx-v-roboti", "font_big", "This line of robots looks familiar.")
dialogStr("Diese Baureihe Roboter sieht bekannt aus.")


dialogId("zx-m-highway", "font_small", "Oh sure, they are from the Highway Encounter.")
dialogStr("Ja sicher, die sind aus Highway Encounter.")


dialogId("zx-v-nahravani", "font_big", "I wonder what is loading right now.")
dialogStr("Ich frage mich, was gerade lädt.")


dialogId("zx-m-ocel", "font_small", "The single biggest advantage of this room is that it contains no steel.")
dialogStr("Der größte Vorteil des Raumes ist, dass hier kein Stahl ist.")
